@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.14';
+$Net::Kubernetes::VERSION = '0.15';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -34,7 +34,7 @@ sub get_namespace {
 	my $res = $self->ua->request($self->create_request(GET => $self->path.'/namespaces/'.$namespace));
 	if ($res->is_success) {
 		my $ns = $self->json->decode($res->content);
-		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, namespace=> $namespace, _namespace_data=>$ns);
+		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, api_version=>$self->api_version, namespace=> $namespace, _namespace_data=>$ns);
 		$create_args{username} = $self->username if(defined $self->username);
 		$create_args{password} = $self->password if(defined $self->password);
 		return Net::Kubernetes::Namespace->new(%create_args);
@@ -94,23 +94,23 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
   my $kube = Net::Kubernets->new(url=>'http://127.0.0.1:8080', username=>'dave', password=>'davespassword');
   my $pod_list = $kube->list_pods();
-  
+
   my $nginx_pod = $kube->create_from_file('kubernetes/examples/pod.yaml');
-  
+
   my $ns = $kube->get_namespace('default');
-  
+
   my $services = $ns->list_services;
-  
+
   my $pod = $ns->get_pod('my-pod');
-  
+
   $pod->delete;
-  
+
   my $other_pod = $ns->create_from_file('./my-pod.yaml');
 
 =head1 METHODS
@@ -176,7 +176,7 @@ returns a list of L<Net::Kubernetes::Resource::Node>s
 
 <h2>Build Status</h2>
 
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.14" />
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.15" />
 
 =end html
 
