@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::APIAccess;
 # ABSTRACT: Role allowing direct access to the REST api
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.14';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.15';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -17,11 +17,18 @@ has url => (
 	default  => 'http://localhost:8080',
 );
 
+has api_version => (
+	is       => 'ro',
+	isa      => 'Str',
+	required => 1,
+);
+
 has base_path => (
 	is       => 'ro',
 	isa      => 'Str',
 	required => 1,
-	default  => '/api/v1beta3',
+	lazy     => 1,
+	builder  => '_create_default_base_path'
 );
 
 has password => (
@@ -74,9 +81,24 @@ around BUILDARGS => sub {
 		$input{token} = do{ local $/; <$fh>};
 		close($fh);
 	}
+	if(! exists $input{api_version}){
+		if(exists $input{base_path}){
+			if($input{base_path} =~ m{/api/(v[^/]+)}){
+				$input{api_version} = $1;
+			}
+		}
+		else {
+			$input{api_version}='v1';
+		}
+	}
 	return $class->$orig(%input);
 };
 
+sub _create_default_base_path {
+	my($self) = @_;
+	return '/api/'.$self->api_version;
+}
+
 sub path {
 	my($self) = @_;
 	return $self->url.$self->base_path;
@@ -120,7 +142,7 @@ Net::Kubernetes::Role::APIAccess - Role allowing direct access to the REST api
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
