@@ -12,7 +12,7 @@ my $ns = $kube->get_namespace('default');
 
 #my $sec = $ns->build_secret('testing', { 'sshpubkeypub' => '/home/dave/.ssh/id_rsa.pub', 'otherthingjson' => {type=>'JSON', value=>{text=>'Ha Ha'}} });
 
-print Dumper($ns->list_events())."\n";
+print Dumper($kube->list_nodes)."\n";
 
 
 
